@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from typing import Tuple
 
 
 class BaseModule(ABC):
@@ -15,3 +16,9 @@ class BaseModule(ABC):
 
     async def _post(self, **params):
         return await self._client._http.post(data={**dict(module=self._module), **params})
+
+    @staticmethod
+    def _check(value: str, values: Tuple[str, ...]):
+        if value and value.lower() not in values:
+            raise ValueError(f'Invalid value {value!r}, only {values} are supported.')
+        return value
